==> percona-server-mongodb_4.0.18.orig.tar.gz: percona-server-mongodb-4.0.18-11/aws-sdk-cpp/aws-cpp-sdk-sagemaker/source/model/MemberDefinition.cpp <==
﻿/*
* Copyright 2010-2017 Amazon.com, Inc. or its affiliates. All Rights Reserved.
*
* Licensed under the Apache License, Version 2.0 (the "License").
* You may not use this file except in compliance with the License.
* A copy of the License is located at
*
*  http://aws.amazon.com/apache2.0
*
* or in the "license" file accompanying this file. This file is distributed
* on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
* express or implied. See the License for the specific language governing
* permissions and limitations under the License.
*/

#include <aws/sagemaker/model/MemberDefinition.h>
#include <aws/core/utils/json/JsonSerializer.h>

#include <utility>

using namespace Aws::Utils::Json;
using namespace Aws::Utils;

namespace Aws
{
namespace SageMaker
{
namespace Model
{

MemberDefinition::MemberDefinition() : 
    m_cognitoMemberDefinitionHasBeenSet(false)
{
}

MemberDefinition::MemberDefinition(JsonView jsonValue) : 
    m_cognitoMemberDefinitionHasBeenSet(false)
{
  *this = jsonValue;
}

MemberDefinition& MemberDefinition::operator =(JsonView jsonValue)
{
  if(jsonValue.ValueExists("CognitoMemberDefinition"))
  {
    m_cognitoMemberDefinition = jsonValue.GetObject("CognitoMemberDefinition");

    m_cognitoMemberDefinitionHasBeenSet = true;
  }

  return *this;
}

JsonValue MemberDefinition::Jsonize() const
{
  JsonValue payload;

  if(m_cognitoMemberDefinitionHasBeenSet)
  {
   payload.WithObject("CognitoMemberDefinition", m_cognitoMemberDefinition.Jsonize());

  }

  return payload;
}

} // namespace Model
} // namespace SageMaker
} // namespace Aws

==> percona-server-mongodb_4.0.27.orig.tar.gz: percona-server-mongodb-4.0.27-22/aws-sdk-cpp/aws-cpp-sdk-sagemaker/source/model/MemberDefinition.cpp <==
﻿/**
 * Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
 * SPDX-License-Identifier: Apache-2.0.
 */

#include <aws/sagemaker/model/MemberDefinition.h>
#include <aws/core/utils/json/JsonSerializer.h>

#include <utility>

using namespace Aws::Utils::Json;
using namespace Aws::Utils;

namespace Aws
{
namespace SageMaker
{
namespace Model
{

MemberDefinition::MemberDefinition() : 
    m_cognitoMemberDefinitionHasBeenSet(false),
    m_oidcMemberDefinitionHasBeenSet(false)
{
}

MemberDefinition::MemberDefinition(JsonView jsonValue) : 
    m_cognitoMemberDefinitionHasBeenSet(false),
    m_oidcMemberDefinitionHasBeenSet(false)
{
  *this = jsonValue;
}

MemberDefinition& MemberDefinition::operator =(JsonView jsonValue)
{
  if(jsonValue.ValueExists("CognitoMemberDefinition"))
  {
    m_cognitoMemberDefinition = jsonValue.GetObject("CognitoMemberDefinition");

    m_cognitoMemberDefinitionHasBeenSet = true;
  }

  if(jsonValue.ValueExists("OidcMemberDefinition"))
  {
    m_oidcMemberDefinition = jsonValue.GetObject("OidcMemberDefinition");

    m_oidcMemberDefinitionHasBeenSet = true;
  }

  return *this;
}

JsonValue MemberDefinition::Jsonize() const
{
  JsonValue payload;

  if(m_cognitoMemberDefinitionHasBeenSet)
  {
   payload.WithObject("CognitoMemberDefinition", m_cognitoMemberDefinition.Jsonize());

  }

  if(m_oidcMemberDefinitionHasBeenSet)
  {
   payload.WithObject("OidcMemberDefinition", m_oidcMemberDefinition.Jsonize());

  }

  return payload;
}

} // namespace Model
} // namespace SageMaker
} // namespace Aws
